@@ -27,7 +27,11 @@ class TrinoCredentials(Credentials):
     port: Port
     user: str
     password: Optional[str] = None
+    jwt_token: Optional[str] = None
+    client_certificate: Optional[str] = None
+    client_private_key: Optional[str] = None
     method: Optional[str] = None
+    cert: Optional[str] = None
     http_headers: Optional[Dict[str, str]] = None
     http_scheme: Optional[str] = None
     session_properties: Optional[Dict[str, Any]] = None
@@ -42,7 +46,7 @@ class TrinoCredentials(Credentials):
         return self.host
 
     def _connection_keys(self):
-        return ("host", "port", "user", "database", "schema")
+        return ('host', 'port', 'user', 'database', 'schema', 'cert')
 
 
 class ConnectionWrapper(object):
@@ -72,13 +76,13 @@ class ConnectionWrapper(object):
         self.handle.close()
 
     def commit(self):
-        self.handle.commit()
+        pass
 
     def rollback(self):
-        self.handle.rollback()
+        pass
 
     def start_transaction(self):
-        self.handle.start_transaction()
+        pass
 
     def fetchall(self):
         if self._cursor is None:
@@ -144,15 +148,14 @@ class TrinoConnectionManager(SQLConnectionManager):
             logger.debug(exc)
             raise dbt.exceptions.RuntimeException(str(exc))
 
+    # For connection in auto-commit mode there is no need to start
+    # separate transaction. If using auto-commit, the client will
+    # create a new transaction and commit/rollback for each query
     def add_begin_query(self):
-        connection = self.get_thread_connection()
-        with self.exception_handler("handle.start_transaction()"):
-            connection.handle.start_transaction()
+        pass
 
     def add_commit_query(self):
-        connection = self.get_thread_connection()
-        with self.exception_handler("handle.commit()"):
-            connection.handle.commit()
+        pass
 
     @classmethod
     def open(cls, connection):
@@ -178,6 +181,28 @@ class TrinoConnectionManager(SQLConnectionManager):
                     "http_scheme must be set to 'https' for 'kerberos' method."
                 )
             http_scheme = "https"
+        elif credentials.method == "jwt":
+            auth = trino.auth.JWTAuthentication(credentials.jwt_token)
+            if credentials.http_scheme and credentials.http_scheme != "https":
+                raise dbt.exceptions.RuntimeException(
+                    "http_scheme must be set to 'https' for 'jwt' method."
+                )
+            if credentials.jwt_token is None:
+                raise dbt.exceptions.RuntimeException(
+                    "jwt_token must be set for 'jwt' method."
+                )
+            http_scheme = "https"
+        elif credentials.method == "certificate":
+            auth = trino.auth.CertificateAuthentication(
+                credentials.client_certificate,
+                credentials.client_private_key,
+            )
+            if credentials.http_scheme and credentials.http_scheme != "https":
+                raise dbt.exceptions.RuntimeException((
+                    "http_scheme must be set to 'https' "
+                    "for 'certificate' method."
+                ))
+            http_scheme = "https"
         else:
             auth = trino.constants.DEFAULT_AUTH
             http_scheme = credentials.http_scheme or "http"
@@ -197,7 +222,8 @@ class TrinoConnectionManager(SQLConnectionManager):
             isolation_level=IsolationLevel.AUTOCOMMIT,
             source="dbt-trino",
         )
-        connection.state = "open"
+        trino_conn._http_session.verify = credentials.cert
+        connection.state = 'open'
         connection.handle = ConnectionWrapper(trino_conn)
         return connection
 
